"use strict";
/**
 * @file This plugin is to access classification text data from different sources. Make sure that
 * the data is conform to expectation.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const sync_1 = __importDefault(require("csv-parse/lib/sync"));
class DataLoader {
    constructor(csvPath, labelColumn) {
        const records = sync_1.default(fs.readFileSync(csvPath), {
            columns: true
        });
        this.records = records.map((record) => {
            const label = record[labelColumn];
            delete record[labelColumn];
            return {
                label,
                data: record
            };
        });
    }
    len() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.records.length;
        });
    }
    getItem(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.records[id];
        });
    }
}
/**
 * the main entry for plugin which is used to access text classification data
 * @param args oneHotTransfer: if current plugin will transfer label data to one-hot (only used when it's not one hot data.)
 */
const csvDataAccess = (args) => __awaiter(void 0, void 0, void 0, function* () {
    const { dataDir, labelColumn } = args;
    const data = {
        dataStatistics: [],
        validationResult: {
            result: true
        },
        trainCsvPath: path.join(dataDir, 'train.csv'),
        validationCsvPath: path.join(dataDir, 'validation.csv'),
        testCsvPath: path.join(dataDir, 'test.csv')
    };
    const names = [];
    if (fs.existsSync(path.join(dataDir, 'train.csv')) && labelColumn) {
        data.trainLoader = new DataLoader(path.join(dataDir, 'train.csv'), labelColumn);
    }
    if (fs.existsSync(path.join(dataDir, 'validation.csv')) && labelColumn) {
        data.validationLoader = new DataLoader(path.join(dataDir, 'validation.csv'), labelColumn);
    }
    if (fs.existsSync(path.join(dataDir, 'test.csv')) && labelColumn) {
        data.testLoader = new DataLoader(path.join(dataDir, 'test.csv'), labelColumn);
    }
    const loader = data.trainLoader || data.validationLoader || data.testLoader;
    if (loader) {
        const data = yield loader.getItem(0);
        names.push(...Object.keys(data.data));
    }
    const result = Object.assign(Object.assign({}, data), { metadata: {
            feature: {
                names
            }
        } });
    return result;
});
exports.default = csvDataAccess;
//# sourceMappingURL=index.js.map